Description Usage Arguments Value Examples
Takes a list of html as input, and returns the information in tabular form.
1 2 | parse_all_listpages(listpagehtml_list,
domain = "https://www.geizhals.at")
|
listpagehtml_list |
List of html structures from a multiple
geizhals pages, each listing items in a selected category,
as gathered via |
domain |
Character vector of length one specifying the domain.
Defaults to |
A tibble (data.frame) containing all information scraped from the geizhals pages.
1 2 3 4 5 6 7 8 9 10 11 | ## Not run:
url_geizhals <- "https://geizhals.at/?cat=acam35"
listpagehtml_list <- fetch_all_listpages(url_geizhals, max_pages = 2)
parse_all_listpages(listpagehtml_list)
url_geizhals <- "https://geizhals.eu/?cat=acam35"
listpagehtml_list <- fetch_all_listpages(url_geizhals, max_pages = 2,
domain = "https://www.geizhals.eu")
parse_all_listpages(listpagehtml_list, domain = "https://www.geizhals.eu")
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.